package My::Plugin;
use Moose;
use MooseX::NonMoose;
use My::File;
extends 'Template::Plugin';

=encoding utf8

=head1 NAME

My::Plugin - an abstract class that inherits from the non-Moose
B<Template::Plugin>.

Depends also on B<Moose>, B<MooseX::NonMoose> and B<My::File>.

=head1 SYNOPSIS

It's an abstract class so you wouldn't instantiate it or use it
directly.  However, if you want to base your own plugin on it, see
B<My::Glob> and B<My::Json> as examples.

=head1 METHODS

=over

=item B<ctx>

The Template::Context object that Template Toolkit passes in on
construction.

=item B<template>

A My::File object that represents the current template input file,
typically named something like 'path/to/foobar.tt2'.

=back

=head1 COPYING

©Copyright <webmaster@acrasis.net>. This is free software; you may
redistribute it and/or modify it under the same terms as Perl itself.

=cut

our $VERSION = 0.1;

has ctx => (is => 'ro', required => 1, isa => 'Template::Context');

has template => (
   is => 'ro', isa => 'My::File',
   builder => '_build_template', lazy => 1,
);

# For how to combine this with an inheriting class, see My::Glob.
sub BUILDARGS {
   my ($class, $ctx) = @_;
   return {  ctx => $ctx };
}

sub _build_template {
   my ($self) = @_;
   return My::File->new(
      path => $self->ctx->stash->get('template')->name,
   );
}

no Moose;
__PACKAGE__->meta->make_immutable;
